@@ -1,4 +1,4 @@
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 library(crosswalkr)
 library(dplyr)
 library(haven)
@@ -10,10 +10,11 @@ df <- tibble(id = c(1:8,10,12,14:16,31,33),
                        'IL','IN','IA','NJ','NY'),
 			 cendiv = c(6,9,8,7,9,8,1,5,5,9,3,3,4,2,2),
 			 cendiv_name = c('East South Central','Pacific','Mountain',
-                             'West South Central','Pacific','Mountain','New England',
-                             'South Atlantic','South Atlantic','Pacific',
-                             'East North Central','East North Central',
-                             'West North Central','Middle Atlantic','Middle Atlantic'))
+                        'West South Central','Pacific','Mountain','New England',
+                        'South Atlantic','South Atlantic','Pacific',
+                        'East North Central','East North Central',
+                        'West North Central','Middle Atlantic',
+                        'Middle Atlantic'))
 			 
 ## crosswalk
 cw <- tibble(cendiv = 1:9,
@@ -23,7 +24,7 @@ cw <- tibble(cendiv = 1:9,
 
 ## -----------------------------------------------------------------------------
 ## encode new column
-df <- df %>%
+df <- df %>% 
     mutate(cenreg = encodefrom(., var = cendiv, cw_file = cw, raw = cendiv,
                                clean = cenreg, label = cenregnm))
 
